@@ -11,13 +11,20 @@ from stoobly_agent.lib.logger import Logger
 class HeaderModel():
 
   def __init__(self, settings: Settings):
-    if not settings.cli.features.remote:
-      self.adapter =  HeaderAdapterFactory(settings.remote).local_db()
-    else:
-      raise('Not yet supported.')
-
     self.settings = settings
 
+    if not settings.cli.features.remote:
+      self.as_local()
+    else:
+      self.as_remote()
+
+  def as_local(self):
+    self.adapter =  HeaderAdapterFactory(self.settings.remote).local_db()
+
+  def as_remote(self):
+    # raise('Not yet supported.')
+    pass
+
   def index(self, request_id: str, **query_params) -> Union[HeaderIndexResponse, None]:
     try:
       return self.adapter.index(request_id, **query_params)
