@@ -8,13 +8,20 @@ from stoobly_agent.lib.logger import Logger
 class ResponseModel():
 
   def __init__(self, settings: Settings):
-    if not settings.cli.features.remote:
-      self.adapter =  ResponseAdapterFactory(settings.remote).local_db()
-    else:
-      raise('Not yet supported.')
-
     self.settings = settings
 
+    if not settings.cli.features.remote:
+      self.as_local()
+    else:
+      self.as_remote()
+
+  def as_local(self):
+    self.adapter =  ResponseAdapterFactory(self.settings.remote).local_db()
+
+  def as_remote(self):
+    # raise('Not yet supported.')
+    pass
+
   def mock(self, request_id: str) -> requests.Response:
     try:
       return self.adapter.mock(request_id)
